@@ -12,7 +12,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::Git::Commit;
 {
-  $Dist::Zilla::Plugin::Git::Commit::VERSION = '2.017';
+  $Dist::Zilla::Plugin::Git::Commit::VERSION = '2.020';
 }
 # ABSTRACT: commit dirty files
 
@@ -22,7 +22,7 @@ use List::Util           qw{ first };
 use Moose;
 use MooseX::Has::Sugar;
 use MooseX::Types::Moose qw{ Str };
-use Path::Class::Dir ();
+use Path::Tiny 0.048 qw(); # subsumes
 use Cwd;
 
 use String::Formatter method_stringf => {
@@ -43,6 +43,11 @@ use String::Formatter method_stringf => {
 with 'Dist::Zilla::Role::AfterRelease';
 with 'Dist::Zilla::Role::Git::Repo';
 with 'Dist::Zilla::Role::Git::DirtyFiles';
+with 'Dist::Zilla::Role::GitConfig';
+
+sub _git_config_mapping { +{
+   changelog => '%{changelog}s',
+} }
 
 # -- attributes
 
@@ -71,7 +76,7 @@ sub after_release {
         my @untracked_files = $git->ls_files( { others=>1, 'exclude-standard'=>1 } );
         foreach my $f ( @untracked_files ) {
             foreach my $path ( @{ $self->add_files_in } ) {
-                if ( Path::Class::Dir->new( $path )->subsumes( $f ) ) {
+                if ( Path::Tiny::path( $path )->subsumes( $f ) ) {
                     push( @output, $f );
                     last;
                 }
@@ -84,6 +89,7 @@ sub after_release {
 
     # write commit message in a temp file
     my ($fh, $filename) = tempfile( getcwd . '/DZP-git.XXXX', UNLINK => 1 );
+    binmode $fh, ':utf8' unless Dist::Zilla->VERSION < 5;
     print $fh $self->get_commit_message;
     close $fh;
 
@@ -139,13 +145,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::Git::Commit - commit dirty files
 
 =head1 VERSION
 
-version 2.017
+version 2.020
 
 =head1 SYNOPSIS
 
